
# Class: expression


todo

URI: [linkml:Expression](https://w3id.org/linkml/Expression)


[![img](https://yuml.me/diagram/nofunky;dir:TB/class/[TypeExpression],[SlotExpression],[TypeExpression]++-%20all_of(i)%200..*>[Expression],[SlotExpression]++-%20all_of(i)%200..*>[Expression],[ClassExpression]++-%20all_of(i)%200..*>[Expression],[TypeExpression]++-%20any_of(i)%200..*>[Expression],[SlotExpression]++-%20any_of(i)%200..*>[Expression],[ClassExpression]++-%20any_of(i)%200..*>[Expression],[TypeExpression]++-%20exactly_one_of(i)%200..*>[Expression],[SlotExpression]++-%20exactly_one_of(i)%200..*>[Expression],[ClassExpression]++-%20exactly_one_of(i)%200..*>[Expression],[TypeExpression]++-%20none_of(i)%200..*>[Expression],[SlotExpression]++-%20none_of(i)%200..*>[Expression],[ClassExpression]++-%20none_of(i)%200..*>[Expression],[AnonymousExpression]uses%20-.->[Expression],[Expression]^-[TypeExpression],[Expression]^-[SlotExpression],[ClassExpression],[AnonymousExpression])](https://yuml.me/diagram/nofunky;dir:TB/class/[TypeExpression],[SlotExpression],[TypeExpression]++-%20all_of(i)%200..*>[Expression],[SlotExpression]++-%20all_of(i)%200..*>[Expression],[ClassExpression]++-%20all_of(i)%200..*>[Expression],[TypeExpression]++-%20any_of(i)%200..*>[Expression],[SlotExpression]++-%20any_of(i)%200..*>[Expression],[ClassExpression]++-%20any_of(i)%200..*>[Expression],[TypeExpression]++-%20exactly_one_of(i)%200..*>[Expression],[SlotExpression]++-%20exactly_one_of(i)%200..*>[Expression],[ClassExpression]++-%20exactly_one_of(i)%200..*>[Expression],[TypeExpression]++-%20none_of(i)%200..*>[Expression],[SlotExpression]++-%20none_of(i)%200..*>[Expression],[ClassExpression]++-%20none_of(i)%200..*>[Expression],[AnonymousExpression]uses%20-.->[Expression],[Expression]^-[TypeExpression],[Expression]^-[SlotExpression],[ClassExpression],[AnonymousExpression])

## Children

 * [SlotExpression](SlotExpression.md) - an expression that constrains the range of values a slot can take
 * [TypeExpression](TypeExpression.md)

## Mixin for

 * [AnonymousExpression](AnonymousExpression.md) (mixin) 

## Referenced by Class

 *  **None** *[all_of](all_of.md)*  <sub>0..\*</sub>  **[Expression](Expression.md)**
 *  **None** *[any_of](any_of.md)*  <sub>0..\*</sub>  **[Expression](Expression.md)**
 *  **None** *[boolean_slot](boolean_slot.md)*  <sub>0..\*</sub>  **[Expression](Expression.md)**
 *  **None** *[exactly_one_of](exactly_one_of.md)*  <sub>0..\*</sub>  **[Expression](Expression.md)**
 *  **None** *[none_of](none_of.md)*  <sub>0..\*</sub>  **[Expression](Expression.md)**

## Attributes

